@@ -29,3 +29,17 @@ class DicomWebServers:
             })
 
         return Job(api_client=self._api_client, orthanc_id=r.json()['ID'])
+
+    def send(self, target_server: str, resources_ids: Union[List[str], str]):
+        """sends a list of resources to a remote DicomWeb server
+        """
+
+        if isinstance(resources_ids, str):
+            resources_ids = [resources_ids]
+
+        self._api_client.post(
+            endpoint=f"{self._url_segment}/{target_server}/stow",
+            json={
+                "Resources": resources_ids,
+                "Synchronous": True
+            })
