@@ -214,7 +214,7 @@ class TestApiClient(unittest.TestCase):
         middle_instance_id = self.oa.series.get_middle_instance_id(orthanc_id=series_id)
         self.assertEqual(instance_id, middle_instance_id)
 
-    def test_send_asynchronous(self):
+    def test_dicomweb_send_asynchronous(self):
         self.oa.delete_all_content()
         self.ob.delete_all_content()
 
@@ -233,6 +233,22 @@ class TestApiClient(unittest.TestCase):
         study_id = self.ob.studies.lookup('1.2.3')
         self.assertIsNotNone(study_id)
 
+    def test_dicomweb_send(self):
+        self.oa.delete_all_content()
+        self.ob.delete_all_content()
+
+        dicom = generate_test_dicom_file(width=33, height=33, tags={'StudyInstanceUID': '1.2.3'})
+        instances_ids = self.oa.upload(dicom)
+        dicom = generate_test_dicom_file(width=33, height=33, tags={'StudyInstanceUID': '1.2.3'})
+        instances_ids.extend(self.oa.upload(dicom))
+
+        study_id = self.oa.studies.lookup('1.2.3')
+
+        job = self.oa.dicomweb_servers.send('orthanc-b', study_id)
+
+        study_id = self.ob.studies.lookup('1.2.3')
+        self.assertIsNotNone(study_id)
+
     def test_modalities_send(self):
         self.oa.delete_all_content()
         self.ob.delete_all_content()
@@ -951,9 +967,10 @@ class TestApiClient(unittest.TestCase):
 
         self.assertEqual(3, len(instances_set.instances_ids))
         # filter 'sT2W/FLAIR'
-        instances_set.filter_instances(filter=lambda api, i: 'sT2W/FLAIR' == api.instances.get(i).series.main_dicom_tags.get('SeriesDescription'))
+        filtered_set = instances_set.filter_instances(filter=lambda api, i: 'sT2W/FLAIR' == api.instances.get(i).series.main_dicom_tags.get('SeriesDescription'))
 
         self.assertEqual(1, len(instances_set.instances_ids))
+        self.assertEqual(2, len(filtered_set.instances_ids))
 
         # apply a metadata to the filtered list of instances
         instances_set.process_instances(processor=lambda api, i: api.instances.set_string_metadata(i, '1024', 'filtered'))
